@@ -172,9 +172,10 @@ int wrong_st_blocks (struct key * key, __u32 * blocks, __u32 sd_blocks, __u16 mo
     int ret = 0;
 
     if (S_ISREG (mode) || S_ISLNK (mode) || S_ISDIR (mode)) {
-	if (*blocks != sd_blocks) {
+	if ((!S_ISLNK(mode) && *blocks != sd_blocks) ||
+	    (S_ISLNK(mode) && *blocks != sd_blocks && (ROUND_UP(*blocks) != sd_blocks))) {
 	    fsck_log ("vpf-10680: The %s %K has the wrong block count in the StatData "
-		"(%u)%s(%u)\n", S_ISDIR (mode) ? "directory" : "file",  key, sd_blocks, 
+		"(%u)%s(%u)\n", S_ISDIR (mode) ? "directory" : S_ISREG (mode) ? "file" : "link",  key, sd_blocks, 
 		fsck_mode(fs) == FSCK_CHECK ? ", should be " : " - corrected to ", *blocks);
 	    ret = 1;
 	}
@@ -541,47 +542,17 @@ static char * get_next_directory_item (struct key * key, /* on return this will
     if (get_offset (key) == DOT_OFFSET) {
 	if (get_ih_entry_count (ih) < 2 ||
 	    name_in_entry_length (ih, deh + 1, 1) != 2 ||
-	    strncmp (name_in_entry (deh + 1, 1), "..", 2))
-	{
-	    fsck_log ("get_next_directory_item: The entry \"..\" cannot be found in %k\n", &ih->ih_key);
-	    pathrelse (&path);
-	    return 0;
-	}
-    }
-
-    /* mark hidden entries as visible, set "." and ".." correctly */
-    deh += *pos_in_item; 
-    for (i = *pos_in_item; i < get_ih_entry_count (ih); i ++, deh ++) {
-	int namelen;
-	char * name;
-
-	name = name_in_entry (deh, i);
-	namelen = name_in_entry_length (ih, deh, i);
-	if (de_hidden (deh))
-	    reiserfs_panic ("get_next_directory_item: item %k: hidden entry %d \'%.*s\'\n",
-			    key, i, namelen, name);
-
-	if (get_deh_offset (deh) == DOT_OFFSET) {
-	    if (not_of_one_file (&(deh->deh2_dir_id), key)) {
-		/* "." must point to the directory it is in */
-		
-		//deh->deh_objectid != REISERFS_ROOT_PARENT_OBJECTID)/*????*/ {
-		fsck_log ("get_next_directory_item: The entry \".\" of the directory %K pointes to %K, instead of %K", 
-		    key, (struct key *)(&(deh->deh2_dir_id)), key);
-		set_deh_dirid (deh, get_key_dirid (key));
-		set_deh_objectid (deh, get_key_objectid (key));
-		mark_buffer_dirty (bh);
-		fsck_log (" - corrected\n");
-	    }
-	}
-
-	if (get_deh_offset (deh) == DOT_DOT_OFFSET) {
-	    /* set ".." so that it points to the correct parent directory */
-	    if (comp_short_keys (&(deh->deh2_dir_id), parent)) {
-		fsck_log ("get_next_directory_item: The entry \"..\" of the directory %K pointes to %K, instead of %K", 
-		    key, (struct key *)(&(deh->deh2_dir_id)), parent);
-		set_deh_dirid (deh, get_key_dirid (parent));
-		set_deh_objectid (deh, get_key_objectid (parent));
+	  6$g2͡#U9+ 9]9LkAix;(C$zsȌO&g',Uoՙ@!yo]-²)sG_7O)L;0/~"ND'"|sZ,k<IB/RNI|7S"a8'P6(F2Ҟ@FqEfpDܢtG,&QY7H!HqLOS34
+XkBeSibs:>]q[cV=Ą]
+mlGH0pSđ|}B'ޫ։ãqbMx9OvJdC9 ^if7nM~R;ɕ}K$MgY
+-9d{~PEm۵ 紸5fӭ^2`IU<qy q4ӳ-F'
+zTd:EglU};nôvéX*)NTlS0{ofǑʲ~X+ Z@B
+5t8UB32f)LË;;=6Qr}vJp)<Ik#X ~=
+tYeF.5H}~QjADJ.0{UA;C)B75Z2M\ڏԐUAob[,1bec]~sxXR.xZ>KW*{0#)zDgv;.<l¯ A'}@tA9y^%*e̔+&&	gվXhTI%
+!鼎*o-DPRiHP8cfV$4(:_ԉL2J{'gSM@V
+:{D7ۘTTbC"ŊZߧ1C@37:pN_WF!n!csEu+ɦ%E5șV qIaUKq]w'1`uhfww7Xvq/`v,<BBT=\BEE y*z#B[j+Iv@#r`<:)Bz
+1=&ƌ_|o/nLVb%g4NrQ4{"˝ڲC[)uib.u}H՛^#qx1,Z?	b)	ȶNU9c*Bs;+zOX"]3/Mkiz:$n[o3bLYQUbye/9VKk7$aIrV4_6=?hNR$G&7ɭ,I- \~WK.I{\sf[`a0u}ILi1@
+8ٲ1}y>[>H$*lfR5	57U{;[ݘV,`y][Gtu,2IiKj#l`,uL		set_deh_objectid (deh, get_key_objectid (parent));
 		mark_buffer_dirty (bh);
 		fsck_log (" - corrected\n");
 	    }
